## $Id: browser.py 17711 2024-03-07 12:57:10Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""UI components for basic applicants and related components.
"""
import grok
from zope.formlib.textwidgets import BytesDisplayWidget
from waeup.kofa.widgets.datewidget import FriendlyDatetimeDisplayWidget
from waeup.kofa.applicants.browser import (
    ApplicantRegistrationPage, ApplicantsContainerPage)
from waeup.kofa.applicants.browser import (
    ApplicantDisplayFormPage,
    ApplicantManageFormPage,
    ApplicantEditFormPage,
    ApplicantRegistrationPage,
    OnlinePaymentDisplayFormPage,
    OnlinePaymentBreadcrumb,
    ExportPDFPaymentSlipPage,
    )
from waeup.kofa.applicants.pdf import PDFApplicationSlip

from kofacustom.udss.applicants.interfaces import (
    ICustomUGApplicant,
    ICustomApplicant,
    ICustomUGApplicantEdit,
    ICustomApplicantOnlinePayment,
    )

from kofacustom.udss.interfaces import MessageFactory as _

OMIT_DISPLAY_FIELDS = ('locked', 'course_admitted',
    'result_uploaded', 'suspended', 'special_application',)

UG_OMIT_DISPLAY_FIELDS = OMIT_DISPLAY_FIELDS + (
    'programme_type', 'course1', 'course2', 'course_admitted')
UG_OMIT_PDF_FIELDS = UG_OMIT_DISPLAY_FIELDS + ('phone',)
UG_OMIT_MANAGE_FIELDS = (
    'special_application',
    'programme_type', 'course1', 'course2', 'course_admitted')
UG_OMIT_EDIT_FIELDS = UG_OMIT_MANAGE_FIELDS + OMIT_DISPLAY_FIELDS + (
    'student_id',
    'notice',
    'jamb_age',
    'jamb_subjects',
    'jamb_score',
    'jamb_reg_number',
    'aggregate')

class CustomApplicantDisplayFormPage(ApplicantDisplayFormPage):
    """A display view for applicant data.
    """

    def _not_paid(self):
        return self.context.state in ('initialized', 'started',)

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomUGApplicant)
        for field in UG_OMIT_PDF_FIELDS:
            form_fields = form_fields.omit(field)
        form_fields['notice'].custom_widget = BytesDisplayWidget
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        return form_fields

class CustomPDFApplicationSlip(PDFApplicationSlip):

    def _addLoginInformation(self):
        """ We do no longer render login information on
        pdf application slips.
        """
        return

    def _reduced_slip(self):
        return getattr(self.context, 'result_uploaded', False)

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomUGApplicant)
        for field in UG_OMIT_PDF_FIELDS:
            form_fields = form_fields.omit(field)
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        return form_fields

class CustomApplicantManageFormPage(ApplicantManageFormPage):
    """A full edit view for applicant data.
    """

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomUGApplicant)
        for field in UG_OMIT_MANAGE_FIELDS:
            form_fields = form_fields.omit(field)
        form_fields['student_id'].for_display = True
        form_fields['applicant_id'].for_display = True
        return form_fields

class CustomApplicantEditFormPage(ApplicantEditFormPage):
    """An applicant-centered edit view for applicant data.
    """

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomUGApplicantEdit)
        for field in UG_OMIT_EDIT_FIELDS:
            form_fields = form_fields.omit(field)
        form_fields['applicant_id'].for_display = True
        form_fields['reg_number'].for_display = True
        return form_fields

    def unremovable(self, ticket):
        return True

